@@ -1,6 +1,7 @@
 import io
 
 import json_stream
+from json_stream.tokenizer import tokenize
 
 
 class IterableStream(io.RawIOBase):
@@ -21,6 +22,13 @@ class IterableStream(io.RawIOBase):
         return True
 
 
-def load(response, persistent=False):
-    f = io.TextIOWrapper(io.BufferedReader(IterableStream(response.iter_content())))
-    return json_stream.load(f, persistent=persistent)
+def _to_file(response):
+    return io.BufferedReader(IterableStream(response.iter_content()))
+
+
+def load(response, persistent=False, tokenizer=tokenize):
+    return json_stream.load(_to_file(response), persistent=persistent, tokenizer=tokenizer)
+
+
+def visit(response, visitor, tokenizer=tokenize):
+    return json_stream.visit(_to_file(response), visitor, tokenizer=tokenizer)
